@@ -16,6 +16,7 @@ from ._core.frozen import (
     FrozenDict,
     FrozenList,
     FrozenTools,
+    NewFrozenList,
 )
 from ._core.maybe import (
     Maybe,
@@ -46,6 +47,9 @@ from ._core.utils import (
 from ._transform.cmd import (
     CmdTransform,
 )
+from ._transform.cmd_smash import (
+    CmdSmash,
+)
 from ._transform.coproduct import (
     CoproductTransform,
 )
@@ -55,14 +59,18 @@ from ._transform.pure_iter import (
 from ._transform.result import (
     ResultTransform,
 )
+from ._transform.result_smash import (
+    ResultSmash,
+)
 from ._transform.stream import (
     StreamTransform,
 )
 
-__version__ = "2.1.2"
+__version__ = "2.5.1"
 __all__ = [
     "Bool",
     "Cmd",
+    "CmdSmash",
     "CmdTransform",
     "CmdUnwrapper",
     "Coproduct",
@@ -72,12 +80,14 @@ __all__ = [
     "FrozenList",
     "FrozenTools",
     "Maybe",
+    "NewFrozenList",
     "PureIter",
     "PureIterFactory",
     "PureIterTransform",
     "Result",
     "ResultE",
     "ResultFactory",
+    "ResultSmash",
     "ResultTransform",
     "Stream",
     "StreamFactory",
