@@ -1,5 +1,7 @@
 """Internal library bug definition."""
 
+from __future__ import annotations
+
 from dataclasses import (
     dataclass,
     field,
@@ -9,19 +11,18 @@ from typing import (
 )
 
 
-@dataclass(frozen=True)
-class _Private:
-    pass
-
-
 @dataclass
 class LibraryBug(Exception):
     """If raised then there is a bug in the `fa_purity` library."""
 
-    _private: _Private = field(repr=False, hash=False, compare=False)
+    @dataclass(frozen=True)
+    class _Private:
+        pass
+
+    _private: LibraryBug._Private = field(repr=False, hash=False, compare=False)
     traceback: Exception
 
     @staticmethod
     def new(exception: Exception) -> NoReturn:
         """Raise a new `LibraryBug` error."""
-        raise LibraryBug(_Private(), exception)
+        raise LibraryBug(LibraryBug._Private(), exception)
