@@ -24,11 +24,6 @@ from .unit import (
 _A = TypeVar("_A")
 
 
-@dataclass(frozen=True)
-class _Private:
-    pass
-
-
 @dataclass(frozen=True)
 class Bool:
     """
@@ -38,16 +33,20 @@ class Bool:
     - lazy evaluation on map
     """
 
-    _private: _Private = field(repr=False, hash=False, compare=False)
+    @dataclass(frozen=True)
+    class _Private:
+        pass
+
+    _private: Bool._Private = field(repr=False, hash=False, compare=False)
     _value: Coproduct[UnitType, UnitType]
 
     @staticmethod
     def true_value() -> Bool:
-        return Bool(_Private(), Coproduct.inl(unit))
+        return Bool(Bool._Private(), Coproduct.inl(unit))
 
     @staticmethod
     def false_value() -> Bool:
-        return Bool(_Private(), Coproduct.inr(unit))
+        return Bool(Bool._Private(), Coproduct.inr(unit))
 
     @classmethod
     def from_primitive(cls, raw: bool) -> Bool:
@@ -67,3 +66,6 @@ class Bool:
             lambda _: ".True",
             lambda _: ".False",
         )
+
+    def __repr__(self) -> str:
+        return str(self)
