@@ -13,5 +13,11 @@ class UnitType:
     To patch it, `UnitType` is the type and `UnitType()` or `unit` is the instance.
     """
 
+    def __str__(self) -> str:
+        return "unit"
+
+    def __repr__(self) -> str:
+        return str(self)
+
 
 unit: UnitType = UnitType()
