@@ -6,6 +6,8 @@ from typing import (
     TypeVar,
 )
 
+from deprecated import deprecated
+
 from fa_purity._core.coproduct import (
     Coproduct,
     CoproductFactory,
@@ -40,7 +42,7 @@ class CoproductTransform(Generic[_L, _R]):
         )
 
     @staticmethod
-    def permutate(
+    def permute(
         item: Coproduct[_A, Coproduct[_B, _C]],
     ) -> Coproduct[Coproduct[_A, _B], _C]:
         factory: CoproductFactory[Coproduct[_A, _B], _C] = CoproductFactory()
@@ -51,3 +53,24 @@ class CoproductTransform(Generic[_L, _R]):
                 lambda c: Coproduct.inr(c),
             ),
         )
+
+    @staticmethod
+    def permute_2(
+        item: Coproduct[Coproduct[_A, _B], _C],
+    ) -> Coproduct[_A, Coproduct[_B, _C]]:
+        factory: CoproductFactory[_A, Coproduct[_B, _C]] = CoproductFactory()
+        return item.map(
+            lambda ab: ab.map(
+                factory.inl,
+                lambda b: factory.inr(Coproduct.inl(b)),
+            ),
+            lambda c: factory.inr(Coproduct.inr(c)),
+        )
+
+    @classmethod
+    @deprecated("Prefer `permute`")  # type: ignore[misc]
+    def permutate(
+        cls,
+        item: Coproduct[_A, Coproduct[_B, _C]],
+    ) -> Coproduct[Coproduct[_A, _B], _C]:
+        return cls.permute(item)
