@@ -1,10 +1,3 @@
-from fa_purity.cmd import (
-    Cmd,
-    unsafe_unwrap,
-)
-from fa_purity.stream.core import (
-    Stream,
-)
 from secrets import (
     randbelow,
 )
@@ -12,14 +5,20 @@ from typing import (
     TypeVar,
 )
 
+from fa_purity import (
+    Cmd,
+    Stream,
+    Unsafe,
+)
+
 _T = TypeVar("_T")
 
 
 def rand_int() -> Cmd[int]:
-    return Cmd.from_cmd(lambda: randbelow(11))
+    return Cmd.wrap_impure(lambda: randbelow(11))
 
 
 def assert_different_iter(stm: Stream[_T]) -> None:
-    iter1 = unsafe_unwrap(stm.unsafe_to_iter())
-    iter2 = unsafe_unwrap(stm.unsafe_to_iter())
+    iter1 = Unsafe.compute(Unsafe.stream_to_iter(stm))
+    iter2 = Unsafe.compute(Unsafe.stream_to_iter(stm))
     assert id(iter1) != id(iter2)
