@@ -1,11 +1,7 @@
-from fa_purity.result import (
+from fa_purity import (
     Result,
-)
-from fa_purity.union import (
     UnionFactory,
-)
-from typing import (
-    Union,
+    Unsafe,
 )
 
 
@@ -18,16 +14,15 @@ def test_use_case_1() -> None:
         .map(lambda i: i + 1)
         .alt(lambda x: f"{x} alt")
     )
-    assert result.unwrap_fail() == f"fail {value + 1} alt"
+    assert (
+        result.map(lambda _: Unsafe.raise_exception(ValueError(None))).to_union()
+        == f"fail {value + 1} alt"
+    )
 
 
 def test_result_with_union() -> None:
     value = "hi"
     _union: UnionFactory[str, int] = UnionFactory()
-    result: Result[Union[str, int], None] = Result.failure(None, int).map(
-        _union.inr
-    )
-    result_2 = result.lash(
-        lambda _: Result.success(value, type(None)).map(_union.inl)
-    )
-    assert result_2.unwrap() == value
+    result: Result[str | int, None] = Result.failure(None, int).map(_union.inr)
+    result_2 = result.lash(lambda _: Result.success(value, type(None)).map(_union.inl))
+    assert result_2.alt(lambda _: Unsafe.raise_exception(ValueError(None))).to_union() == value
