@@ -19,5 +19,5 @@ def test_composite() -> None:
         lambda x: f.inl(x),
         lambda c: f.inr(CoproductTransform(c).swap()),
     )
-    z = CoproductTransform.permutate(k)
+    z = CoproductTransform.permute(k)
     assert z == y
